====================
Bare Metal Community
====================

This document provides information on how to reach out to the community for
questions, bug reports or new code contributions.

Useful Links
============

Bug/Task tracker
    https://bugs.launchpad.net/ironic/+bugs

Code Hosting
    https://opendev.org/openstack/ironic

Code Review
    https://review.opendev.org/#/q/status:open+project:openstack/ironic,n,z

Weekly Meeting Agenda
    https://wiki.openstack.org/wiki/Meetings/Ironic#Agenda_for_next_meeting

Ironic Contributors' Whiteboard
    https://etherpad.opendev.org/p/IronicWhiteBoard

Asking Questions
================

There are two many venues where all discussions happen: IRC and mailing lists.

Internet Relay Chat 'IRC'
-------------------------

Daily contributor discussions take place on IRC in the ``#openstack-ironic``
channel on the OFTC IRC network.  Please feel free to connect to
``ircs://irc.oftc.net:6697`` and join our channel!

Note that while we have community members from everywhere in the world, we're
the most active from roughly 6am to 12am. If you don't get an answer to your
question, try the `Mailing list`_.

Additional information on getting connected can be found in the
`OpenStack community contribution guide <https://docs.openstack.org/contributors/common/irc.html>`_.

Mailing list
------------

We use the *openstack-discuss* mailing list for asynchronous communications and
longer discussions. Navigate to
http://lists.openstack.org/cgi-bin/mailman/listinfo/openstack-discuss
to subscribe or view the archives.

When sending a message please prefix the *Subject* line with ``[ironic]`` so
that we don't miss it.

Reporting Bugs
==============

See :doc:`bugs` for more details on how we track bugs.

LaunchPad
---------

Most of the tools used for OpenStack require a Launchpad_ ID for
authentication. Ironic tracks bugs via Launchpad.

.. _Launchpad: https://launchpad.net

Storyboard
----------

The Ironic project moved from `StoryBoard
<https://storyboard.openstack.org/>`_ for work and task tracking in
April, 2023. Ironic bugs in storyboard may remain valid, but there
should not be additional issues filed there.


Contributing Code
=================

.. seealso::

   * :doc:`contributing` - basic information on new code contributions
   * :doc:`/contributor/index`
